@@ -1,4 +1,4 @@
-# $Id: Article.pm,v 1.3 2003/09/04 07:32:23 cvspub Exp $
+# $Id: Article.pm,v 1.5 2003/09/14 08:09:43 cvspub Exp $
 package WWW::Google::Groups::Article;
 use strict;
 our $VERSION = '0.01';
@@ -7,8 +7,8 @@ use Email::Simple;
 
 sub new {
     my ($pkg, $message) = @_;
-    return unless $$message;
-    my $mail = Email::Simple->new($$message);
+    return Email::Simple->new($$message) if $$message;
+    undef;
 }
 
 
